import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:pmd_lab/components/locale/l10n/app_locale.dart';
import 'package:pmd_lab/presentation/home_page/bloc/bloc.dart';

import 'package:pmd_lab/presentation/home_page/home_page.dart';
import 'package:pmd_lab/presentation/like_bloc/like_bloc.dart';
import 'package:pmd_lab/presentation/locale_bloc/locale_bloc.dart';
import 'package:pmd_lab/presentation/locale_bloc/locale_state.dart';
import 'package:pmd_lab/repositories/titans_repository.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocProvider<LocaleBloc>(
      lazy: false,
      create: (context) => LocaleBloc(Locale(Platform.localeName)),
      child: BlocBuilder<LocaleBloc, LocaleState>(
        builder: (context, state) {
          return MaterialApp(
            locale: state.currentLocale,
            localizationsDelegates: AppLocale.localizationsDelegates,
            supportedLocales: AppLocale.supportedLocales,
            debugShowCheckedModeBanner: false,
            theme: ThemeData(
              primarySwatch: Colors.orange,
              scaffoldBackgroundColor: Color(0x33BDBCBC),
              useMaterial3: true,
            ),
            home: RepositoryProvider<TitansRepository>(
              lazy: true,
              create: (_) => TitansRepository(),
              child: BlocProvider<LikeBloc>(
                lazy: false,
                create: (context) => LikeBloc(),
                child: BlocProvider<HomeBloc>(
                  lazy: false,
                  create: (context) => HomeBloc(context.read<TitansRepository>()),
                  child: const MyHomePage(),
                ),
              ),
            ),
          );
        },
      ),
    );
  }
}
