import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:pmd_lab/components/extensions/context_x.dart';
import 'package:pmd_lab/components/utils/debounce.dart';
import 'package:pmd_lab/domain/models/card.dart';
import 'package:pmd_lab/presentation/common/svg_objects.dart';
import 'package:pmd_lab/presentation/details_page/details_page.dart';
import 'package:pmd_lab/presentation/home_page/bloc/bloc.dart';
import 'package:pmd_lab/presentation/home_page/bloc/events.dart';
import 'package:pmd_lab/presentation/home_page/bloc/state.dart';
import 'package:pmd_lab/presentation/like_bloc/like_bloc.dart';
import 'package:pmd_lab/presentation/like_bloc/like_event.dart';
import 'package:pmd_lab/presentation/like_bloc/like_state.dart';
import 'package:pmd_lab/presentation/locale_bloc/locale_events.dart';
import 'package:pmd_lab/presentation/locale_bloc/locale_state.dart';
import 'package:pmd_lab/repositories/titans_repository.dart';
import '../locale_bloc/locale_bloc.dart';
part 'card.dart';

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key});
  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  Widget build(BuildContext context) {
    return const Scaffold(body: Body());
  }
}

class Body extends StatefulWidget {
  const Body({super.key});
  @override
  State<Body> createState() => _BodyState();
}

class _BodyState extends State<Body> {
  final searchController = TextEditingController();
  @override
  void initState() {
    SvgObjects.init();
    WidgetsBinding.instance.addPostFrameCallback((_) {
      context.read<HomeBloc>().add(const HomeLoadDataEvent());
      context.read<LikeBloc>().add(const LoadLikesEvent());
    });
    super.initState();
  }


  @override
  void dispose() {
    searchController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: MediaQuery.of(context).padding.top),
      child: Column(
        children: [
          Row(
            children: [
              Expanded(
                flex: 4,
                child: Padding(
                  padding: const EdgeInsets.all(12),
                  child: CupertinoSearchTextField(
                    controller: searchController,
                    placeholder: context.locale.search,
                    backgroundColor: Colors.white12,
                    placeholderStyle: TextStyle(
                      color: Colors.white, // Задайте желаемый цвет плейсхолдера// (Необязательно) Задайте размер шрифта(Необязательно) Задайте стиль шрифта
                    ),
                    style: TextStyle(
                      color: Colors.white,
                    ),
                    onChanged: (search) {
                      Debounce.run(() => context.read<HomeBloc>().add(HomeLoadDataEvent(search: search)));
                    },
                  ),
                ),
              ),
              GestureDetector(
                onTap: () => context.read<LocaleBloc>().add(const ChangeLocaleEvent()),
                child: SizedBox.square(
                  dimension: 50,
                  child: Padding(
                    padding: const EdgeInsets.only(right: 12),
                    child: BlocBuilder<LocaleBloc, LocaleState>(
                      builder: (context, state) {
                        return state.currentLocale.languageCode == 'ru'
                            ? const SvgRu()
                            : const SvgUk();
                      },
                    ),
                  ),
                ),
              ),
            ],
          ),

          BlocBuilder<HomeBloc, HomeState>(
            builder: (context, state) => state.error != null
                ? Text(
                    state.error ?? '',
                    style: Theme.of(context).textTheme.headlineSmall?.copyWith(color: Colors.red),
                  )
                : state.isLoading
                    ? const CircularProgressIndicator()
                    : BlocBuilder<LikeBloc, LikeState>(
                        builder: (context, likeState) {
                          return Expanded(
                            child: RefreshIndicator(
                              onRefresh: _onRefresh,
                              child: ListView.builder(
                                physics: const BouncingScrollPhysics(),
                                padding: const EdgeInsets.all(12),
                                itemCount: state.data?.data?.length ?? 0,
                                itemBuilder: (context, index) {
                                  final data = state.data?.data?[index];
                                  return data != null
                                      ? _Card.fromData(
                                    data,
                                    onLike: _onLike,
                                    isLiked: likeState.likedIds?.contains(
                                        data.id) == true,
                                    onTap: () => _navToDetails(context, data),
                                  )
                                      : const SizedBox.shrink();
                                },
                              ), // ListView.builder
                            ), // RefreshIndicator
                          );
                        },
                      ), // Expanded
          ) // BlocBuilder
        ],
      ),
    );
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          '$title ${isLiked ? context.locale.liked : context.locale.disliked}',
          style: Theme.of(context).textTheme.bodyLarge,
        ),
        backgroundColor: Colors.white,
        duration: const Duration(seconds: 1),
      ));
    });
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }

  Future<void> _onRefresh() {
    context.read<HomeBloc>().add(HomeLoadDataEvent(search: searchController.text));
    return Future.value(null);
  }

  void _onLike(String? id, String title, bool isLiked) {
    if (id != null) {
      context.read<LikeBloc>().add(ChangeLikeEvent(id.toString()));
      _showSnackBar(context, title, !isLiked);
    }
  }
}
