import 'package:dio/dio.dart';
import 'package:pmd_lab/data/dtos/titans_dto.dart';
import 'package:pmd_lab/data/mappes/titans_mapper.dart';
import 'package:pmd_lab/domain/models/card.dart';
import 'package:pmd_lab/domain/models/home.dart';
import 'package:pmd_lab/repositories/api_interface.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

class TitansRepository extends ApiInterface {
  static final Dio _dio = Dio()
    ..interceptors.add(PrettyDioLogger(
      requestHeader: true,
      requestBody: true,
    ));

  static const String _baseUrl = 'https://api.attackontitanapi.com';

  @override
  Future<HomeData?> loadResults({
    OnErrorCallback? onError,
    String? q
  }) async {
    try {
      const String url = '$_baseUrl/titans';

      final Response<dynamic> response = await _dio.get<Map<dynamic, dynamic>>(
        url,
        queryParameters: q != null ? {'name': q} : null,
      );

      final TitansDto dto = TitansDto.fromJson(response.data as Map<String, dynamic>);
      final HomeData data = dto.toDomain();
        return data;
      } on DioException catch (e) {
      onError?.call(e.error?.toString());
      return null;
    }
  }
}
